@@ -2,7 +2,7 @@
 import sys
 
 
-__version__ = '4.4.0'
+__version__ = '4.5.0'
 
 API_PATH = {
     'about_edited':           'r/{subreddit}/about/edited/',
@@ -90,6 +90,18 @@ API_PATH = {
     'my_multireddits':        'api/multi/mine/',
     'my_subreddits':          'subreddits/mine/subscriber/',
     'marknsfw':               'api/marknsfw/',
+    'modmail_archive':        'api/mod/conversations/{id}/archive',
+    'modmail_bulk_read':      'api/mod/conversations/bulk/read',
+    'modmail_conversation':   'api/mod/conversations/{id}',
+    'modmail_conversations':  'api/mod/conversations/',
+    'modmail_highlight':      'api/mod/conversations/{id}/highlight',
+    'modmail_mute':           'api/mod/conversations/{id}/mute',
+    'modmail_read':           'api/mod/conversations/read',
+    'modmail_subreddits':     'api/mod/conversations/subreddits',
+    'modmail_unarchive':      'api/mod/conversations/{id}/unarchive',
+    'modmail_unmute':         'api/mod/conversations/{id}/unmute',
+    'modmail_unread':         'api/mod/conversations/unread',
+    'modmail_unread_count':   'api/mod/conversations/unread/count',
     'multireddit':            'user/{user}/m/{multi}/',
     'multireddit_api':        'api/multi/user/{user}/m/{multi}/',
     'multireddit_base':       'api/multi/',
