@@ -1,6 +1,5 @@
 """Provide the Comment class."""
-from six.moves.urllib.parse import urljoin  # pylint: disable=import-error
-
+from ...const import urljoin
 from ...exceptions import ClientException
 from ..comment_forest import CommentForest
 from .base import RedditBase
@@ -21,14 +20,14 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
 
     @property
     def mod(self):
-        """An instance of :class:`.CommentModeration`."""
+        """Provide an instance of :class:`.CommentModeration`."""
         if self._mod is None:
             self._mod = CommentModeration(self)
         return self._mod
 
     @property
     def replies(self):
-        """An instance of :class:`.CommentForest`."""
+        """Provide an instance of :class:`.CommentForest`."""
         if isinstance(self._replies, list):
             self._replies = CommentForest(self.submission, self._replies)
         return self._replies
@@ -119,7 +118,7 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
     def permalink(self, fast=False):
         """Return a permalink to the comment.
 
-        :param fast: Return the result as quickly as possible (Default: False).
+        :param fast: Return the result as quickly as possible (default: False).
 
         In order to determine the full permalink for a comment, the Submission
         may need to be fetched if it hasn't been already. Set ``fast=True`` if
